@@ -1,4 +1,6 @@
 import argparse
+from pathlib import Path
+import sys
 from ids_validator.convention_versions import Conventions
 from ids_validator.ids_validator import validate_ids
 
@@ -12,4 +14,8 @@ if __name__ == "__main__":
     parser.add_argument("--version", type=str, required=False, default=None,
                         help=f"Supported Versions: {Conventions.values()}")
     args = parser.parse_args()
-    validate_ids(args)
\ No newline at end of file
+    ids_dir = Path(args.ids_dir)
+
+    result = validate_ids(ids_dir, args.version)
+    return_code = 0 if result is True else 1
+    sys.exit(return_code)
